eure-cli 0.1.5

Command-line tool for Eure format conversion and validation
eure-cli-0.1.5 is not a library.
Visit the last successful build: eure-cli-0.0.0

eure-cli

Command-line interface for working with Eure files.

This crate provides utilities for converting Eure to other formats, validating Eure files, and more.

This crate is still under development and published for name reservation purpose.

Part of the Eure project - a minimalist, schema-friendly format with an algebraic data model that's compatible with JSON.