build_runtime

Function build_runtime 

pub fn build_runtime() -> QueryRuntime
Build a query runtime with the standard Eure configuration.

This includes:

  • TextFileLocator for URL host validation against security.allowed-hosts
  • error_reports_comparator for proper ErrorReports comparison

All consumers should use this function to ensure consistent behavior.