get_validation_errors_formatted_explicit

Function get_validation_errors_formatted_explicit 

pub fn get_validation_errors_formatted_explicit(
    db: &impl Db,
    doc_file: TextFile,
    schema_file: TextFile,
) -> Result<Vec<String>, QueryError>
Validate document against an explicitly provided schema and return formatted error strings.

Use this when you have a specific schema file to validate against.

Returns empty vec if either document or schema parsing failed. Returns formatted error messages suitable for display.