TargetsValidationResult

Struct TargetsValidationResult 

pub struct TargetsValidationResult {
    pub target_results: Vec<(String, TargetValidationResult)>,
}
Result of validating multiple targets.

Fields

target_results: Vec<(String, TargetValidationResult)>

Results per target: (name, result).

Implementations

Source

impl TargetsValidationResult

pub fn is_ok(&self) -> bool

Returns true if all targets passed validation.

pub fn total_files_checked(&self) -> usize

Returns total number of files checked across all targets.

pub fn total_error_count(&self) -> usize

Returns total number of files with errors across all targets.