ErrorReports

Struct ErrorReports 

pub struct ErrorReports(/* private fields */);
A collection of error reports.

Implementations

Source

impl ErrorReports

pub fn len(&self) -> usize

Returns the number of elements in the collection.

pub fn is_empty(&self) -> bool

Returns true if the collection contains no elements.

pub fn iter(&self) -> impl Iterator<Item = &ErrorReport>

Iterates over the collection.

pub fn capacity(&self) -> usize

Returns the capacity of the collection.

pub fn reserve(&mut self, additional: usize)

Reserves capacity for at least additional more elements to be inserted in the collection.

pub fn with_capacity(capacity: usize) -> Self

Construct a new empty collection with the specified capacity.

pub fn new() -> Self

Creates a new, empty collection.

pub fn clear(&mut self)

Clears the collection, removing all values.

Source

impl ErrorReports

pub fn push(&mut self, report: ErrorReport)

Add a new error report to the collection.

pub fn pop(&mut self) -> Option<ErrorReport>

Remove and return the last error report.

pub fn get_mut(&mut self, index: usize) -> Option<&mut ErrorReport>

Get a mutable reference to a report at a specific index.

pub fn replace(&mut self, index: usize, report: ErrorReport)

Replace a report at a specific index.

pub fn sort_by_span(&mut self)

Sort reports by their primary origin span start position.