pub struct ErrorReports(/* private fields */);Expand description
A collection of error reports.
Implementations
Sourceimpl ErrorReports
impl ErrorReports
Sourcepub fn iter(&self) -> impl Iterator<Item = &ErrorReport>
pub fn iter(&self) -> impl Iterator<Item = &ErrorReport>
Iterates over the collection.
Sourcepub fn reserve(&mut self, additional: usize)
pub fn reserve(&mut self, additional: usize)
Reserves capacity for at least additional more elements to be inserted in the collection.
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Construct a new empty collection with the specified capacity.
Sourceimpl ErrorReports
impl ErrorReports
Sourcepub fn push(&mut self, report: ErrorReport)
pub fn push(&mut self, report: ErrorReport)
Add a new error report to the collection.
Sourcepub fn pop(&mut self) -> Option<ErrorReport>
pub fn pop(&mut self) -> Option<ErrorReport>
Remove and return the last error report.
Sourcepub fn get_mut(&mut self, index: usize) -> Option<&mut ErrorReport>
pub fn get_mut(&mut self, index: usize) -> Option<&mut ErrorReport>
Get a mutable reference to a report at a specific index.
Sourcepub fn replace(&mut self, index: usize, report: ErrorReport)
pub fn replace(&mut self, index: usize, report: ErrorReport)
Replace a report at a specific index.
Sourcepub fn sort_by_span(&mut self)
pub fn sort_by_span(&mut self)
Sort reports by their primary origin span start position.